EveryCheckpointSchedule
=======================

.. currentmodule:: pykeen.checkpoints

.. autoclass:: EveryCheckpointSchedule
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~EveryCheckpointSchedule.frequency

   .. rubric:: Methods Summary

   .. autosummary::

      ~EveryCheckpointSchedule.__call__

   .. rubric:: Attributes Documentation

   .. autoattribute:: frequency

   .. rubric:: Methods Documentation

   .. automethod:: __call__
